Core (``taurex.core``)
=======================

Retrieval
---------

.. automodule:: taurex.data.fittable
   :members:
   :undoc-members:
   :show-inheritance:


Bibliography
------------

.. automodule:: taurex.data.citation
   :members:
   :undoc-members:
   :show-inheritance:

Priors (``taurex.core.priors``)
===============================

.. automodule:: taurex.core.priors
   :members:
   :undoc-members:
   :show-inheritance:
